(function polyfill() {
  const relList = document.createElement("link").relList;
  if (relList && relList.supports && relList.supports("modulepreload")) {
    return;
  }
  for (const link of document.querySelectorAll('link[rel="modulepreload"]')) {
    processPreload(link);
  }
  new MutationObserver((mutations) => {
    for (const mutation of mutations) {
      if (mutation.type !== "childList") {
        continue;
      }
      for (const node of mutation.addedNodes) {
        if (node.tagName === "LINK" && node.rel === "modulepreload")
          processPreload(node);
      }
    }
  }).observe(document, { childList: true, subtree: true });
  function getFetchOpts(link) {
    const fetchOpts = {};
    if (link.integrity)
      fetchOpts.integrity = link.integrity;
    if (link.referrerPolicy)
      fetchOpts.referrerPolicy = link.referrerPolicy;
    if (link.crossOrigin === "use-credentials")
      fetchOpts.credentials = "include";
    else if (link.crossOrigin === "anonymous")
      fetchOpts.credentials = "omit";
    else
      fetchOpts.credentials = "same-origin";
    return fetchOpts;
  }
  function processPreload(link) {
    if (link.ep)
      return;
    link.ep = true;
    const fetchOpts = getFetchOpts(link);
    fetch(link.href, fetchOpts);
  }
})();
var WpGolfScore;
((WpGolfScore2) => {
  const getElements = () => {
    return document.querySelectorAll("[data-golf-score]");
  };
  async function getForecast(cfg) {
    return await fetch("/wp-content/plugins/wp-golf-score/proxy.php?lat=" + cfg.lat + "&lon=" + cfg.lon).then((response) => response.json()).then((data) => data.forecast);
  }
  const mapValue = (limits, values, value) => {
    let response = values[0];
    limits.forEach((v, index) => {
      if (value > v) {
        response = values[index + 1];
      }
    });
    return response;
  };
  const calculateScore = (dayOfWeek, month, temp, clouds, rain, thunder, wind) => {
    const dayOfWeekScore = [9, 1, 4, 5, 5, 8, 10][dayOfWeek] * 4;
    const monthScore = [1, 1, 5, 8, 10, 10, 8, 7, 8, 6, 3, 1][month] * 7;
    const tempScore = mapValue([10, 20, 30, 35], [1, 3, 10, 8, 5], temp) * 10;
    const windScore = mapValue([8, 14], [10, 8, 3], wind) * 6;
    const cloudsScore = mapValue([30, 60], [9, 10, 7], clouds) * 3;
    const rainScore = mapValue([0, 2.5, 8], [10, 6, 5, 1], rain) * 10;
    const thunderScore = mapValue([10, 40], [10, 6, 1], thunder) * 10;
    const score = dayOfWeekScore + monthScore + tempScore + windScore + cloudsScore + rainScore + thunderScore;
    console.log("calculateScore for", dayOfWeek, month, temp, wind, rain, clouds, thunder);
    console.log("calculateScore", dayOfWeek, month, temp, wind, rain, clouds, thunder);
    return Math.round(score / 50);
  };
  const getScore = (forecast) => {
    const score = {
      dprev: 5,
      d0: 5,
      d1: 5,
      d2: 5
    };
    let dd;
    for (dd = -1; dd <= 2; dd++) {
      const date = /* @__PURE__ */ new Date();
      date.setMilliseconds(0);
      date.setHours(0);
      date.setMinutes(0);
      date.setSeconds(0);
      date.setDate(date.getDate() + dd);
      const start = Math.floor(date.getTime() / 1e3);
      const end = start + 24 * 60 * 60;
      const dayForecast = Object.values(forecast).filter((f) => {
        if (f.ts >= start && f.ts <= end) {
          const date2 = new Date(f.ts * 1e3);
          return date2.getHours() >= 8 && date2.getHours() <= 20;
        }
        return false;
      });
      if (dayForecast.length > 0) {
        const dayOfWeek = date.getDay();
        const month = date.getMonth();
        const temp = Math.max(...dayForecast.map((f) => {
          return f.air_temperature;
        }));
        const clouds = dayForecast.map((f) => {
          return f.cloud_area_fraction ?? 100;
        }).reduce((previousValue, currentValue) => {
          return previousValue + currentValue;
        }) / dayForecast.length;
        const wind = Math.max(...dayForecast.map((f) => {
          return f.wind_speed ?? 0;
        }));
        const rain = Math.max(...dayForecast.map((f) => {
          return f.precipitation_amount ?? 0;
        }));
        const thunder = Math.max(...dayForecast.map((f) => {
          return f.probability_of_thunder ?? 0;
        }));
        switch (dd) {
          case -1:
            score.dprev = calculateScore(dayOfWeek, month, temp, clouds, rain, thunder, wind);
            break;
          default:
            score["d" + dd] = calculateScore(dayOfWeek, month, temp, clouds, rain, thunder, wind);
            break;
        }
      } else {
        console.warn("Forecast not available", start, end);
      }
    }
    return score;
  };
  const processScore = (element, score) => {
    let i;
    let prevScore = score.dprev;
    const empty = element.querySelectorAll("[data-day]").length === 0;
    for (i = 0; i <= 2; i++) {
      const dayScore = score["d" + i];
      let target = element.querySelector("[data-day='" + i + "']");
      if (target === null && empty) {
        target = document.createElement("span");
        target.setAttribute("data-day", i.toString());
        element.append(target);
      }
      if (target !== null) {
        if (element.getAttribute("data-date-element") === "1") {
          target.classList.add("with-date");
          let dateElement = target.querySelector("[data-date]");
          if (dateElement === null) {
            dateElement = document.createElement("span");
            dateElement.setAttribute("data-date", "1");
            target.append(dateElement);
          }
          let date = /* @__PURE__ */ new Date();
          date.setDate(date.getDate() + i);
          dateElement.textContent = date.toLocaleString("cs-CZ", {
            weekday: "short",
            month: "numeric",
            day: "numeric"
          });
        } else {
          target.classList.remove("with-date");
        }
        const icon = "/wp-content/plugins/wp-golf-score/static/img/" + (dayScore > prevScore ? "up" : dayScore < prevScore ? "dn" : "eq") + ".png";
        let iconElement = target.querySelector("img");
        if (iconElement === null) {
          iconElement = document.createElement("img");
          iconElement.setAttribute("src", icon);
          target.append(iconElement);
        }
        let scoreElement = target.querySelector("[data-score]");
        if (scoreElement === null) {
          scoreElement = document.createElement("span");
          scoreElement.setAttribute("data-score", "");
          target.append(scoreElement);
        }
        scoreElement.textContent = dayScore.toString();
      }
      prevScore = dayScore;
    }
  };
  const doUpdate = async () => {
    const elements = getElements();
    for (const element of elements) {
      const cfgS = element.dataset.golfScore;
      if (typeof cfgS === "string") {
        try {
          const cfg = JSON.parse(cfgS);
          if (cfg.lat && cfg.lon) {
            getForecast(cfg).then(
              (forecast) => {
                const score = getScore(forecast);
                processScore(element, score);
              }
            );
          }
        } catch (e) {
          console.error("Can't parse wp-golf-score config");
        }
      }
    }
  };
  WpGolfScore2.init = () => {
    let initInterval = setInterval(() => {
      if (getElements().length > 0) {
        if (initInterval !== void 0) {
          clearInterval(initInterval);
          doUpdate();
          setInterval(() => {
            doUpdate();
          }, 30 * 60 * 1e3);
        }
      }
    }, 1e3);
  };
})(WpGolfScore || (WpGolfScore = {}));
WpGolfScore.init();
